@@ -15,7 +15,7 @@ BEGIN {
 
 use File::Basename;
 
-our $VERSION = '6.57_05';
+our $VERSION = '6.58';
 
 require ExtUtils::MM_Any;
 require ExtUtils::MM_Unix;
@@ -248,6 +248,23 @@ sub find_perl {
     0; # false and not empty
 }
 
+=item _fixin_replace_shebang (override)
+
+Helper routine for MM->fixin(), overridden because there's no such thing as an
+actual shebang line that will be intepreted by the shell, so we just prepend
+$Config{startperl} and preserve the shebang line argument for any switches it
+may contain.
+
+=cut
+
+sub _fixin_replace_shebang {
+    my ( $self, $file, $line ) = @_;
+
+    my ( undef, $arg ) = split ' ', $line, 2;
+
+    return $Config{startperl} . "\n" . $Config{sharpbang} . "perl $arg\n";
+}
+
 =item maybe_command (override)
 
 Follows VMS naming conventions for executable files.
